package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0D```````````(`/@`!````X!Q```````!``````````*"=````
M`````````$``.``(`$``&@`9``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$```````(R6````````C)8`````````
M`"````````$````&````D)8```````"0EF```````)"68```````1`0`````
M``!8"0``````````(````````@````8```"XE@```````+B68```````N)9@
M``````#P`0```````/`!````````"``````````$````!````!@"````````
M&`)````````8`D```````!@`````````&``````````$`````````%#E=&0$
M````@)(```````"`DD```````("20```````Q`````````#$``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"``````````O;&EB97AE8R]L9"UE;&8N<V\N,0`````(````
M!`````$```!&<F5E0E-$`(B_#0!#````7``````````,`````````%0```!$
M``````````````!0`````````$8```!-````,@```#,````E`````````%<`
M``!6`````````$<```!;```````````````#````"0```#$````C````6@``
M`#\```!,````10```"(`````````!P`````````O````/@``````````````
M'0```#D`````````4P````````!`````$0```"8````M````/``````````[
M````2@``````````````%@```#@````L````00````````!5````4@``````
M``!.`````0```!H````Z````/0```%D`````````````````````````````
M````````````````````````````````````````````"P````4`````````
M```````````.```````````````/`````````!``````````````````````
M``````````````````````````@````8````````````````````!@``````
M```*````````````````````$P`````````K````%````!4`````````%P``
M``(```````````````0````-````)````"H````9````(```````````````
M'P```#`````>````-P```"$``````````````!P````T```````````````2
M````0P`````````I````-@````````!(````+@```$(````H````2P```"<`
M````````40```$\`````````-0```%@````;````20``````````````````
M``````````````````````"4`0``$@``````````````(0$```````!5`P``
M$@`,`&`X0```````!0````````!F`P``$@`,`/`=0```````-`````````!L
M````$@``````````````%0````````#+`P``$@``````````````'@``````
M```E`P``$@`,`.`<0```````G`````````!V````$0`7`.":8```````!```
M``````"!````$@``````````````B@8````````^`@``$@``````````````
M```````````-````$@``````````````K`````````",````$@```%P90```
M````2@`````````2````(``````````````````````````S`@``$0`6`+":
M8```````"`````````"?````$@`-`*110`````````````````!S`P``$@`,
M`#!-0```````P`,```````")`P``$@`,`'`U0```````30````````"7`P``
M$@`,`)`W0```````R0````````"E````$@``````````````(00```````"N
M````$@``````````````4P$```````"\````$@``````````````5P``````
M``"M`P``$@`,`*`]0```````X@````````"Y`P``$@`,`'`]0```````(@``
M``````#,````$@``````````````=`$```````!Z`@``$@``````````````
M+P````````"H`@``$@``````````````#`````````#4`P``$@`,`)`^0```
M````;0````````#``@``$@`````````````````````````*`P``$@``````
M````````;`````````#W`@``$@````````````````````````#:````$@``
M````````````5`$```````#.`@``$@```````````````@`````````2`P``
M$@``````````````50````````#?`@``$@``````````````V0````````#G
M`@``$@``````````````D``````````_````$@``````````````2@``````
M``#E````$@``````````````>0````````!T`@``$@``````````````9P``
M``````!E`@``$@``````````````]`````````#S````$@```(P:0```````
M^`$````````#`0``$@```)P:0```````2@`````````F````$@``````````
M````<0`````````4`0``$@``````````````B0`````````E`0``$@``````
M````````2P@```````#O`@``$@``````````````(0````````#V`@``$@``
M``````````````````````#8`@``$@````````````````````````!7`@``
M$@````````````````````````!1`@``$@````````````````````````#@
M`P``$@`,`/!00```````*@````````!=`@``$@``````````````-```````
M```T`0``$@``````````````IP$```````!#`0``$@``````````````L`$`
M``````!-````$@``````````````T`````````!1`0``$@``````````````
M1AH````````K````$@``````````````10````````"!`@``$@``````````
M``````````````"X`@``$@``````````````3`````````"7`@``$@``````
M````````#``````````@`P``$`#Q_]2:8`````````````````!?`0``$0`7
M`."?8```````"`````````!G`0``$@``````````````_0`````````K`@``
M$@``````````````CQ````````!%````$@``````````````,0````````!L
M`@``$@``````````````"@`````````D`@``$@``````````````2@``````
M``!S`0``$@``````````````I0`````````2`@``$0`7``";8```````0```
M``````#\`@``$@``````````````?``````````L`P``$`#Q_^B?8```````
M``````````"(`@``$@````````````````````````#'`@``$@``````````
M````5`````````"(`0``$@``````````````.P````````";`0``$0`7`$";
M8````````0````````"H`0``$0`7`%";8```````$P````````!\`@``$@``
M````````````+P````````#H`P``$@`,`/!"0```````/@H````````9`P``
M$`#Q_]2:8`````````````````!Q````$@``````````````#0<```````"W
M`0``$@``````````````<P````````#U`P``$@`,`)`Z0```````%P$`````
M```'!```$@`,`"!!0```````Q@$````````4!```$0`6`,B:8```````"```
M``````#"`0``$@``````````````G`````````"/`@``$@``````````````
M2@````````"O`@``$@``````````````FP````````!'`@``$0`7`(";8```
M````"``````````#`P``$@``````````````?@`````````>!```$@`,`+`[
M0```````O@$````````K!```$@`,```_0```````&`(```````#B`P``$@`*
M`-@80`````````````````#1`0``$@``````````````X0<`````````;&EB
M=&AR+G-O+C,`;W!E;@!?2G9?4F5G:7-T97)#;&%S<V5S`')E860`<'1H<F5A
M9%]G971S<&5C:69I8P!C;&]S90!?7V5R<F]R`'!T:')E861?871F;W)K`&QI
M8G!E<FPN<V\N-2XR,`!P97)L7V9R964`4$Q?=&AR7VME>0!P97)L7W!A<G-E
M`%!E<FQ?871F;W)K7W5N;&]C:P!?9FEN:0!P97)L7W)U;@!097)L7V%V7W-H
M:69T`%!E<FQ?9W9?9F5T8VAP=@!097)L7W-V7W-E='!V`'!E<FQ?86QL;V,`
M4&5R;%]S>7-?=&5R;0!B;V]T7T1Y;F%,;V%D97(`4&5R;%]A=&9O<FM?;&]C
M:P!097)L7VYE=UA37V9L86=S`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?<W9?<V5T
M<'9N`%!E<FQ?879?9F5T8V@`<&5R;%]D97-T<G5C=`!E;G9I<F]N`%!E<FQ?
M;6=?<V5T`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?<V%F97-Y<VUA;&QO
M8P!03%]D;U]U;F1U;7``4$Q?;65M;W)Y7W=R87``4&5R;%]N97=84P!097)L
M7W-Y<U]I;FET,P!097)L7W-V7S)P=E]F;&%G<P!L:6)M+G-O+C4`;&EB8W)Y
M<'0N<V\N-0!L:6)U=&EL+G-O+CD`;&EB8RYS;RXW`%]?<W1A8VM?8VAK7V=U
M87)D`&UE;6-P>0!R96%L;&]C`%]?<')O9VYA;64`<F5A9&QI;FL`7U]S=&1E
M<G)P`')M9&ER`&UK9&ER`'-T<FYC;7``<W1R;&5N`&]P96YD:7(`;'-E96L`
M871E>&ET`&%C8V5S<P!G971P:60`;65M;6]V90!?7W-T86-K7V-H:U]F86EL
M`'-T<G1O:P!C;&]S961I<@!S=')N8W!Y`'5N;&EN:P!M96US970`7VEN:71?
M=&QS`&=E='5I9`!F<')I;G1F`'-P<FEN=&8`;65M8VAR`&QS=&%T`'-T<G-T
M<@!S=')C;7``<F5A9&1I<@!S=')D=7``7V5D871A`%]?8G-S7W-T87)T`%]E
M;F0`+W5S<B]L;V-A;"]L:6(O<&5R;#4O-2XR,"]M86-H+T-/4D4`<&%R7V-U
M<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4
M`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N
M86UE`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'AS
M7VEN:70`<&%R7VUK=&UP9&ER`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD
M<')O9P!M>5]P87)?<&P`<&%R7VEN:71?96YV`&UA:6X`1D)31%\Q+C``````
M`@`!``$````"``$```````(``P```````0`!``$``0`!``````````$``0``
M``(``@`!``(``@`"`````@`"``(``@`#`````@`"```````#```````"``(`
M`@`"``(``0`"```````#`````P`"``(``@`!``$````"``,``@`"`````@`"
M``$``@`"``````````(``0`!``(````!``$``0````(``@`"``(``0`!``$`
M```````````!``$``0```!`````@````L"AZ!P```P`P!`````````$``0`(
M`@``$`````````"P*'H'```"`#`$````````X)I@```````%````!P``````
M`````````)M@```````%````0P``````````````0)M@```````%````20``
M````````````4)M@```````%````2@``````````````@)M@```````%````
M5@``````````````P)A@```````'`````0``````````````R)A@```````'
M````!```````````````T)A@```````'````!0``````````````V)A@````
M```'````"```````````````X)A@```````'````"0``````````````Z)A@
M```````'````"@``````````````\)A@```````'````"P``````````````
M^)A@```````'````$@```````````````)E@```````'````$P``````````
M````")E@```````'````%```````````````$)E@```````'````%P``````
M````````&)E@```````'````&```````````````()E@```````'````&0``
M````````````*)E@```````'````&P``````````````,)E@```````'````
M'```````````````.)E@```````'````'0``````````````0)E@```````'
M````'@``````````````2)E@```````'````'P``````````````4)E@````
M```'````(```````````````6)E@```````'````(0``````````````8)E@
M```````'````(@``````````````:)E@```````'````(P``````````````
M<)E@```````'````)```````````````>)E@```````'````)0``````````
M````@)E@```````'````)@``````````````B)E@```````'````)P``````
M````````D)E@```````'````*```````````````F)E@```````'````*0``
M````````````H)E@```````'````*@``````````````J)E@```````'````
M*P``````````````L)E@```````'````+```````````````N)E@```````'
M````+0``````````````P)E@```````'````+@``````````````R)E@````
M```'````+P``````````````T)E@```````'````,```````````````V)E@
M```````'````,@``````````````X)E@```````'````,P``````````````
MZ)E@```````'````-```````````````\)E@```````'````-0``````````
M````^)E@```````'````-@```````````````)I@```````'````-P``````
M````````")I@```````'````.```````````````$)I@```````'````.0``
M````````````&)I@```````'````.@``````````````()I@```````'````
M/0``````````````*)I@```````'````/@``````````````,)I@```````'
M````/P``````````````.)I@```````'````0```````````````0)I@````
M```'````00``````````````2)I@```````'````0@``````````````4)I@
M```````'````1```````````````6)I@```````'````1@``````````````
M8)I@```````'````1P``````````````:)I@```````'````2```````````
M````<)I@```````'````2P``````````````>)I@```````'````3@``````
M````````@)I@```````'````3P``````````````B)I@```````'````4P``
M````````````D)I@```````'````5```````````````F)I@```````'````
M50``````````````H)I@```````'````5P``````````````J)I@```````'
M````6P``````````````2(/L".C?!```Z(HX``!(@\0(PP#_-;Y_(`#_)<!_
M(``/'T``_R6^?R``:`````#IX/____\EMG\@`&@!````Z=#_____):Y_(`!H
M`@```.G`_____R6F?R``:`,```#IL/____\EGG\@`&@$````Z:#_____)99_
M(`!H!0```.F0_____R6.?R``:`8```#I@/____\EAG\@`&@'````Z7#_____
M)7Y_(`!H"````.E@_____R5V?R``:`D```#I4/____\E;G\@`&@*````Z4#_
M____)69_(`!H"P```.DP_____R5>?R``:`P```#I(/____\E5G\@`&@-````
MZ1#_____)4Y_(`!H#@```.D`_____R5&?R``:`\```#I\/[___\E/G\@`&@0
M````Z>#^____)39_(`!H$0```.G0_O___R4N?R``:!(```#IP/[___\E)G\@
M`&@3````Z;#^____)1Y_(`!H%````.F@_O___R46?R``:!4```#ID/[___\E
M#G\@`&@6````Z8#^____)09_(`!H%P```.EP_O___R7^?B``:!@```#I8/[_
M__\E]GX@`&@9````Z5#^____)>Y^(`!H&@```.E`_O___R7F?B``:!L```#I
M,/[___\EWGX@`&@<````Z2#^____)=9^(`!H'0```.D0_O___R7.?B``:!X`
M``#I`/[___\EQGX@`&@?````Z?#]____);Y^(`!H(````.G@_?___R6V?B``
M:"$```#IT/W___\EKGX@`&@B````Z<#]____):9^(`!H(P```.FP_?___R6>
M?B``:"0```#IH/W___\EEGX@`&@E````Z9#]____)8Y^(`!H)@```.F`_?__
M_R6&?B``:"<```#I</W___\E?GX@`&@H````Z6#]____)79^(`!H*0```.E0
M_?___R5N?B``:"H```#I0/W___\E9GX@`&@K````Z3#]____)5Y^(`!H+```
M`.D@_?___R56?B``:"T```#I$/W___\E3GX@`&@N````Z0#]____)49^(`!H
M+P```.GP_/___R4^?B``:#````#IX/S___\E-GX@`&@Q````Z=#\____)2Y^
M(`!H,@```.G`_/___R4F?B``:#,```#IL/S___\E'GX@`&@T````Z:#\____
M)19^(`!H-0```.F0_/___R4.?B``:#8```#I@/S___\E!GX@`&@W````Z7#\
M____)?Y](`!H.````.E@_/___R7V?2``:#D```#I4/S___\E[GT@`&@Z````
MZ4#\____)>9](`!H.P```.DP_/___R7>?2``:#P```#I(/S___\EUGT@`&@]
M````Z1#\__\`````54B)Y4%53(UO"$%44TB#[`B+'TACPX7;3(UDQQ!,B27<
M@B``?CI(BU<(2(72=#%(B16:?2``#[8"A,!T(TB#P@$\+TB+!89](`!(#T3"
M2(D%>WT@``^V`DB#P@&$P'7AN+B68`!(A<!T*TB)]^A:_/__OZ110`#H4/S_
M_^AW^___B=],B>),B>[HDB$``(G'Z.?^___HDOS__^O6D)"0D(`]`7X@``!5
M2(GE=!#K))!(@\`(2(D%)7T@`/_22(L%''T@`$B+$$B%TG7DQ@75?2```<G#
M#Q]$``!F#Q]$``!52(,]YW@@``!(B>5T%K@`````2(7`=`R_L)9@`$F)P\E!
M_^/)PY"0D)"0D)"0D)`/M@](B?B$R70H2(L%QS4``$B-5P$/MC!(B?@/'T0`
M`$`X\0^V"D@/1,)(@\(!A,EU[O/#9@\?1```9@\?1```059(C7<X055!5%5(
MB?U32('L"`(``$R-3"2(38V!@````$R)STB+#DB#Q@A(B<I(B<A(P>((2,'@
M&"4```#_@>(``/\`2`G"2(G(2,'H""4`_P``2`G"2(G(2,'H&"7_````2`G"
M2(G(2,'I*$C!Z"!(B1=(P>`(2(G"2,'@$"4```#_@>(``/\`2`G"2(G(2,'I
M$"4`_P``2`G"2`G*2(E7"$B#QQ!,.<</A77___])C4EH28VQ:`(```\?1```
M2(L!2#-!V$@S0:A(,T&82(G"2`'`2,'J'T@)PH/B_TB)41A(@\$(2#GQ==1,
MBW4`2(M\)(A!O=R\&X](`WT@2(M-"$R+51!(BW483(GP3(GR38GQ2,'B!4C!
MZ!M)B<A("=!,B=))P>@"@^#_2"'*2<'I`DB-O`>9>8):2(G(2,'A'DCWT$D)
MR$@A\$&#X/](`W0DD$@)T$R)P@''3(GP3"'R2/?02(GY3"'02,'I&TP#5"28
M2`G"2(GX2,'@!4B-M!:9>8):2(GZ2`G!3(GP2,'@'@'Q20G!2(GX2(G.08/A
M_TCWT$C![AM,(<I,(<!("=!(B<I-C90"F7F"6DB)R$C!X`5("<9(B<A$`=9)
MB?I(]]!)P>H"2,'G'DP#1"2@20GZ3"'(2(GW08/B_TC![QM,`TPDJ$PATD@)
MT$B)\DV-A`"9>8):2(GP2,'@!4@)QTB)\$0!QTF)R$C!X1Y)P>@"2/?020G(
M3"'02(GY08/@_TC!Z1M,`U0DL$PAPD@)T$B)^DV-C`&9>8):2(GX2,'@!4@)
MP4B)^$0!R4F)\4C!YAY)P>D"2/?020GQ3"'`2(G.08/A_TC![AM,(<I("=!(
MB<I-C90"F7F"6DB)R$C!X`5,`T0DN$@)QDB)R$0!UDF)^DC!YQY)P>H"2/?0
M20GZ3"'(2(GW08/B_TC![QM,`TPDP$PATD@)T$B)\DV-A`"9>8):2(GP2,'@
M!4@)QTB)\$0!QTF)R$C!X1Y)P>@"2/?020G(3"'02(GY08/@_TC!Z1M,`U0D
MR$PAPD@)T$B)^DV-C`&9>8):2(GX2,'@!4@)P4B)^$0!R4F)\4C!YAY)P>D"
M2/?020GQ3"'`2(G.08/A_TPARDC![AM,`T0DT$@)T$B)RDV-E`*9>8):2(G(
M2,'@!4@)QDB)R$0!UDF)^DC!YQY)P>H"2/?020GZ3"'(2(GW08/B_TC![QM,
M`TPDV$PATD@)T$B)\DV-A`"9>8):2(GP2,'@!4@)QTB)\$0!QTF)R$C!X1Y)
MP>@"2/?020G(3"'02(GY08/@_TC!Z1M,(<)("=!(B?I-C8P!F7F"6DB)^$C!
MX`5("<%(B?A$`<E)B?%(P>8>2<'I`DCWT$D)\4B)SD&#X?],`U0DX$PAP$PA
MRDC![AM,`T0DZ$@)T$B)RDV-E`*9>8):2(G(2,'@!4@)QDB)R$0!UDF)^DC!
MYQY)P>H"2/?020GZ3"'(2(GW08/B_TC![QM,`TPD\$PATD@)T$B)\DV-A`"9
M>8):2(GP2,'@!4@)QTB)\$0!QTF)R$C!X1Y)P>@"2/?020G(3"'02(GY08/@
M_TC!Z1M,(<)("=!(B?I-C8P!F7F"6DB)^$C!X`5("<%(B?A$`<E)B?%(]]!)
MP>D"2,'F'DP#5"3X20GQ3"'`2(G.08/A_TC![AM,`P0D3"'*2`G02(G*38V4
M`IEY@EI(B<A(P>`%2`G&2(G(1`'628GZ2,'G'DG!Z@)(]]!)B?-)"?I,(<A(
MB?=!@^+_2,'O&TP#3"0(3"'22`G02(GR38V$`)EY@EI(B?!(P>`%2`G'2(GP
M1`''28G(2,'A'DG!Z`)(]]!)"<A,(=!(B?E!@^#_2,'I&TPAPD@)T$B)^DV-
MC`&9>8):2(GX2,'@!4C!YAY)P>L"3`-4)!!("<%)"?-(B?A!@^/_1`')2/?0
M3"':2(G.3"'`28GY2,'N&T@)T$C!YQY)P>D"38V4`IEY@EI(B<A,`T0D&$C!
MX`5)"?E(B<I("<9(B<A!@^'_2/?03"'*1`'63"'82(GW28G*2`G02,'A'DC!
M[QM-C80`F7F"6DB)\$G!Z@)(P>`%3`-<)"!)"<I("<=(B?!!@^+_2(GR2/?0
M1`''3"'(28GP3"'22`G02,'F'DG!Z`)-C9P#F7F"6DD)\$B)^DB)^$&#X/],
M`TPD*$C!X`5(P>H;2`G"3(G`3#'01`':3`-4)#!(,?A(B=%-C8P!H>O9;DB)
MT$C!Z1M(P>`%2`G!1`')28GY2,'G'DG!Z0)(B<Y)"?E(B==(P>X;08/A_TC!
M[P),B<A,,<!,`T0D.$@QT$C!XAY-C90"H>O9;D@)UTB)R(/G_TC!X`5("<9(
MB?A$`=9,,<A,`TPD0$@QR$B)\DV-A`"AZ]EN2(GP2,'J&TC!X`5("<)$`<))
MB<A(P>$>2<'H`DD)R$B)T4&#X/](P>D;3(G`2#'X2`-\)$A(,?!-C8P!H>O9
M;DB)T$C!X`5("<%$`<E)B?%(P>8>2<'I`DD)\4B)SD&#X?](P>X;3(G(3#'`
M3`-$)%!(,=!(C;P'H>O9;DB)R$C!X`5("<8!_DB)UTC!XAY(P>\"2`G72(GR
M@^?_2(GX3#'(2,'J&TP#3"182#'(38V$`*'KV6Y(B?!(P>`%2`G"1`'"28G(
M2,'A'DG!Z`))"<A(B=%!@^#_2,'I&TR)P$@Q^$@#?"1@2#'P38V,`:'KV6Y(
MB=!(P>`%2`G!1`')28GQ2,'F'DG!Z0))"?%(B<Y!@^'_2,'N&TR)R$PQP$P#
M1"1H2#'02(V\!Z'KV6Y(B<A(P>`%2`G&`?Y(B==(P>(>2,'O`D@)UTB)\H/G
M_TB)^$PQR$C!ZAM,`TPD<$@QR$V-A`"AZ]EN2(GP2,'@!4@)PD0!PDF)R$C!
MX1Y)P>@"20G(2(G108/@_TC!Z1M,B<!(,?A(`WPD>$@Q\$V-C`&AZ]EN2(G0
M2,'@!4@)P40!R4F)\4C!YAY)P>D"20GQ2(G.08/A_TC![AM,B<A,,<!,`X0D
M@````$@QT$B-O`>AZ]EN2(G(2,'@!4@)Q@'^2(G72,'B'DC![P)("==(B?*#
MY_](B?A,,<A(P>H;3`.,)(@```!(,<A-C80`H>O9;DB)\$C!X`5("<)$`<))
MB<A(P>$>2<'H`DD)R$B)T4&#X/](P>D;3(G`2#'X2`.\))````!(,?!-C8P!
MH>O9;DB)T$C!X`5("<%$`<E)B?%(P>8>2<'I`DD)\4B)SD&#X?](P>X;3(G(
M3#'`3`.$))@```!(,=!(C;P'H>O9;DB)R$C!X`5("<8!_DB)UTC!XAY(P>\"
M2`G72(GR@^?_2(GX3#'(2,'J&TP#C"2@````2#'(38V$`*'KV6Y(B?!(P>`%
M2`G"1`'"28G(2,'A'DG!Z`))B=))"<A(B=%)P>H"08/@_TC!Z1M,B<!(,?A(
M`[PDJ````$@Q\$V-C`&AZ]EN2(G02,'@!4@)P40!R4F)\4C!YAY)P>D"28G,
M20GQ2(G.08/A_TC![AM,B<A,,<!,`X0DL````$@QT$C!XAY(C;P'H>O9;DD)
MTDB)R$&#XO](P>`%2`G&3(G0`?Y,,<A)P>P"2#'(2,'A'DB)\DV-A`"AZ]EN
M20G,2(GP08/D_TP#C"2X````2,'@!4C!ZAM(B?-(BXPDR````$@)PDR)X$C!
MZP),,=!$`<),`Y0DP````$@Q\$C!YAY(B==-C8P!H>O9;D@)\TB)T(/C_TC!
MX`5(P>\;2`G'2(G828G33#'@1`'/2<'K`D@QT$C!XAY)B?A-C90"H>O9;DD)
MTTB)^$&#X_](P>`%2<'H&TD)P$P!Z4R)V$4!T$R)VDP!X4@)V$@AVDR)QD@A
M^$F)^4C![AM("=!(P><>2<'I`D@!P4R)P$D)^4C!X`5!@^'_38G"2`G&3(G(
M3(G*`<Y(BXPDT````$P)V$PAVDPAP$B)]T@)T$C![QM)P>`>3`'I2<'J`D&\
MUL%BRD@!V4T)PD@!P4B)\$&#XO](P>`%3(G22`G'3(G0`<](BXPDV````$P)
MR$@A\$F)^$P!Z4P!V4PARDF)\T@)T$C!YAY)P>@;2`'!2(GX2<'K`DC!X`5)
M"?-)"<!!@^/_00'(2(N,).````!,B=A,"=!,B=I,B<9,(=)((?A(P>X;3`'I
M2`G03`')28GY2,'G'D@!P4R)P$G!Z0)(P>`%20GY2`G&08/A_P'.2(N,).@`
M``!,B<A,"=A,B<I(B?=,(=I,(<!,`>E("=!,`=%-B<)(`<%(B?!(P>\;2,'@
M!4G!X!Y)P>H"2`G'30G"`<]!@^+_2(N,)/````!,B=!,B=))B?A,"<A,(<I)
MP>@;3`'I2"'P2`G03`'928GS2`'!2(GX2,'F'DC!X`5)P>L"20G`20GS00'(
M08/C_TB+C"3X````3(G83(G:3(G&3`G03"'22,'N&TP!Z4@A^$@)T$P!R4F)
M^4@!P4R)P$C!X`5("<8!SDC!YQY)P>D"20GY2(N,)``!``!(B?=!@^'_2,'O
M&TR)R$R)RDP)V$PAVDP!Z4PAP$P!T4V)PD@)T$G!X!Y)P>H"2`'!2(GP30G"
M2,'@!4&#XO]("<=,B=!,B=(!STB+C"0(`0``3`G(3"'*2"'P28GX2`G02<'H
M&TP!Z4P!V4F)\TC!YAY(`<%(B?A)P>L"2,'@!4D)P$$!R$D)\TB+C"00`0``
M08/C_TR)QDR)V$R)VDC![AM,"=!,(=),`>E((?A,`<E)B?E("=!(P><>2<'I
M`D@!P4R)P$D)^4C!X`5!@^'_2`G&3(G(3(G*`<Y(BXPD&`$``$P)V$PAVDPA
MP$B)]T@)T$C![QM,`>E,`=%-B<))P>`>2`'!2(GP2<'J`DC!X`5-"<)("<=!
M@^+_`<](BXPD(`$``$R)T$R)TDF)^$P!Z4P!V4P)R$PARD@A\$F)\TG!Z!M(
M"=!(P>8>2<'K`D@!P4B)^$D)\TC!X`5!@^/_20G`3(G83(G:00'(2(N,)"@!
M``!,"=!,(=)((?A,B<9("=!(P>X;3`'I3`')28GY2,'G'D@!P4R)P$G!Z0)(
MP>`%20GY2`G&08/A_P'.2(N,)#`!``!,B<A,"=A,B<I(B?=,(<!,`>E,`=%,
M(=I-B<)("=!)P>`>2,'O&T@!P4B)\$G!Z@)(P>`%30G"2`G'08/B_P'/2(N,
M)#@!``!,B=!,"<A,B=))B?A,(<I((?!)P>@;3`'I2`G03`'928GS2,'F'D@!
MP4B)^$G!ZP)(P>`%20GS20G`08/C_T$!R$B+C"1``0``3(G83`G03(G:3(G&
M3"'22"'X3`'I2`G03`')28GY2`'!3(G`2,'N&TC!X`5(P><>2<'I`D@)QDD)
M^0'.08/A_TB+C"1(`0``3(G(3(G*2(GW3`G83"':2,'O&TP!Z4PAP$@)T$P!
MT4V)PD@!P4B)\$G!X!Y(P>`%2<'J`D@)QTT)P@'/08/B_TB+C"10`0``3(G0
M3(G228GX3`G(3"'*2<'H&TP!Z4@A\$@)T$P!V4F)\T@!P4B)^$C!X`5)"<!!
M`<A(P>8>2<'K`DD)\TB+C"18`0``3(G&08/C_TC![AM,B=A,B=I,`>E,"=!,
M(=),`<E((?A)B?E("=!(P><>2<'I`D@!P4D)^4R)P$&#X?],`ZPD8`$``$C!
MX`5("<9,B<A,B<I,"=A,(=H!SDPAP$B)]T@)T$T!U4C![QM)`<5(B?!-B<)(
MP>`%2<'@'DG!Z@)("<=(BY0D:`$``$0![TT)PDF)\$&#XO](B?E)P>@"3(G0
M3`'B2,'I&TPQR$P!VD@Q\$C!YAY(`<)(B?A)"?!(P>`%08/@_T@)P4R)P`'1
M2(N4)'`!``!,,=!(,?A(B<Y(P>X;3`'B3`'*28GY2,'G'D@!PDB)R$G!Z0)(
MP>`%20GY2`G&08/A_P'62(N4)'@!``!,B<A,,<!(B?=(,<A,`>),`=))B<I(
M`<)(B?!(P>\;2,'@!4C!X1Y)P>H"2`G'20G*`==(BY0D@`$``$&#XO],B=!(
MB?E,,<A(P>D;3`'B2#'P3`'"28GP2,'F'D@!PDB)^$G!Z`)(P>`%20GP2`G!
M08/@_P'12(N4)(@!``!,B<!,,=!(B<Y(,?A(P>X;3`'B3`'*28GY2,'G'D@!
MPDB)R$G!Z0)(P>`%20GY2`G&`=9(BY0DD`$``$&#X?],B<A(B?=,,<!(P>\;
M3`'B2#'(3`'228G*2,'A'D@!PDB)\$G!Z@)(P>`%20G*2`G'08/B_P'72(N4
M))@!``!,B=!,,<A(B?E(,?!(P>D;3`'B3`'"28GP2,'F'D@!PDB)^$G!Z`)(
MP>`%20GP2`G!08/@_P'12(N4)*`!``!,B<!,,=!(B<Y(,?A(P>X;3`'B3`'*
M28GY2`'"2(G(2,'@!4C!YQY)P>D"2`G&20GY`=9(BY0DJ`$``$&#X?],B<A(
MB?=,,<!(P>\;3`'B2#'(3`'228G*2,'A'D@!PDB)\$G!Z@)(P>`%20G*2`G'
M08/B_P'72(N4)+`!``!,B=!,,<A(B?E(,?!(P>D;3`'B3`'"28GP2,'F'D@!
MPDB)^$G!Z`)(P>`%20GP2`G!08/@_P'12(N4)+@!``!,B<!(B<Y,`>),,=!(
MP>X;2#'X3`'*28GY2`'"2(G(2,'G'DC!X`5)P>D"2`G&20GY`=9(BY0DP`$`
M`$&#X?],B<A(B?=,,<!(P>\;3`'B2#'(3`'228G*2,'A'D@!PDB)\$G!Z@)(
MP>`%20G*2`G'08/B_P'72(N4),@!``!,B=!,,<A(B?E(,?!(P>D;3`'B3`'"
M28GP2`'"2(GX2,'@!4@)P4C!YAY)P>@"`=%)"?!(BY0DT`$``$&#X/](B<Y,
MB<!(P>X;3`'B3#'02#'X3`'*28GY2`'"2(G(2,'G'DC!X`5)P>D"2`G&20GY
M`=9(BY0DV`$``$&#X?],B<A(B?=)B?-,,<!(P>\;3`'B2#'(3`'228G*2,'A
M'D@!PDB)\$G!Z@)(P>`%20G*2`G'08/B_P'72(N4).`!``!,B=!(B?E(B?M,
M`>),`<),,<A(P>D;2#'P2<'K`DC!YAY(`<)(B?A)"?-(P>`%08/C_TC!ZP)(
M"<%,B=@!T4B+E"3H`0``3#'02#'X28G(2,'G'DG!Z!M("?M,`>*#X_],`<I)
MB<E(`<)(B<A(P>`%20G`2(G800'02(N4)/`!``!,,=A(,<A,B<=,B<9(P>\;
M3`'B3`'22`'"3(G`2,'@!4@)QP'72,'A'DG!Z0))"<E(BY0D^`$``$C![@)!
M@^'_2(GY3(G(2,'I&TP!XD@QV$P#I"0``@``3#'`3`':2<'@'D@!PDP)QDB)
M^$C!X`6#YO]("<%(B?!)`=Q,,<@!T4@Q^$B)RDD!Q$B)R$C!X@5(P>@;2`G0
M1`'@1`'P2(E%`$B)^$C!YQY(P>@"`TT(2`GX`T40`W481`--($B)30A(B440
M2(EU&$R)32!(@<0(`@``6UU!7$%=05[#3(ED).!,B7PD^$F)_$B)7"302(EL
M)-A)B?=,B6PDZ$R)="3P2(/L.$B%_W4E,<!(BUPD"$B+;"003(MD)!A,BVPD
M($R+="0H3(M\)#!(@\0XPTR+-6=K(`!-A?9TSP^V!X3`=00QP.L7/#U(B?IT
M]4B#P@$/M@*$P'5%B=!$*>!)BRY(A>UTI4QCZ$R)\V:03(GJ3(GF2(GOZ&[F
M__^%P'4*28U$+0"`.#UT&DB+:PA(@\,(2(7M==?I;____V:0/#UUK.NU3"GS
M2(/``4C!^P-!B1_I5O___P\?@`````!54TB)^TB#[!A(C6PD%&:0,<!(B>Y(
MB=_H`____TB%P'0F2&-$)!1(C13%`````$@#%:IJ(`!(@\((2(L"2(7`2(E"
M^'7PZ\A(@\086UW#D$B#[!@QP$B-="04Z,#^__](@\08PP\?1```9@\?1```
M2(/L"(,]564@`/]T"XL%364@`$B#Q`C#,<"_N%%``.B\____2(7`=`</M@"$
MP'43,<")!2AE(`"+!2)E(`!(@\0(PSPP#Y7`#[;`Z^4/'P!,B60DZ$B)7"38
M28G\2(EL).!,B6PD\$R)="3X2('LJ````$B%_W0%@#\`=3-(BYPD@````$B+
MK"2(````3(ND))````!,BZPDF````$R+M"2@````2('$J````,,/'P#HQ^7_
M_TB%P$B)Q73`#Q\`2(GOZ*3C__](A<`/A*$```!(C5@(O\-10`"Y`@```/Q(
MB=[SIG39O\)10`"Y`P```$B)WO.F=,A,B>?H#.3__TB)WTF)Q>@!Y/__08U$
M!0)(8_CH=.+__TB)V4B)QTF)Q4R)XK[%44``,<#HG./__TB)YDR)[^A!X___
M@\`!=!$/MT0D""4`\```/0!```!T-DR)[^@#X___3(GOZ)OE__](B>_H`^/_
M_TB%P`^%7____TB)[^C"Y?__3(GGZ"KD___I]O[__TR)[^C!_O__D.O'#Q^`
M``````\?@`````!32(G[BSW&8R``Z%WD__](C;"8`0``2(G?Z+[C__^%P'0$
M6S'`PXL]I&,@`.@[Y/__#[>`H`$``"4`\```/0!```!T'HL]AF,@`.@=Y/__
M#[>`H`$``"4`\```/0"@``!UP$B)W[X"````Z`WD__];A<`/E,`/ML###Q^`
M`````$B)7"3H2(EL)/!,B60D^$B![#@(``!(C9PD$`0``$B+!4MC(`!(B80D
M&`@``#'`Z&CD__^Y95-``(G"OLM10``QP$B)W^ABXO__A<!Y-C'M2(N4)!@(
M``!(,Q418R``2(GH=6!(BYPD(`@``$B+K"0H"```3(ND)#`(``!(@<0X"```
MPTB)W[H`!```2(GFZ!CA__^%P(G#>+2->`%(8__HQ^#__TB%P'2D2&/;2(G%
M2(GF2(G:2(G'Z*[C___&!"L`ZXSH4^/__P\?@`````#I*____P\?1```9@\?
M1```05<QP$%628G^055!5%5(B?532(/L&(`^/0^4P$@!Q4B)[^CEX?__2(UT
M)!1)B<=,B?<QP.AW^___2(7`2(G#=#1(B<?HP^'__TDYQP^'OP````^V10!(
M@\4!B`-(@\,!A,!U[DB#Q!@QP%M=05Q!74%>05_#2(L]]&8@`$4QY+@0````
M2(,_`'0B2(GZ#Q\`2(M""$&#Q`%(@\((2(7`=>]!C40D`DB82,'@`XL5?F(@
M`(72#X4C`0``2(G'QP5I8B```0```.C`W___2(7`28G%#X0I`0``26/$2(LU
MCF8@`$R)[TB-',4`````2(G:Z#?C__],B2UT9B``2(L%;68@`$C'1`,(````
M`$2)9"0400^V%DR)\(32#X2V````@/H]#X2M````#Q^``````$B#P`$/MA"$
MT@^%B0```$0I\$B82&-<)!1*C7PX`DC!XP-(`QT79B``Z"[?__](A<!(B0,/
MA)<```!(8U0D%$B+!?IE(`!(BQ3000^V!H3`B`)T(CP]=!Y,B??K"P\?`$B#
MQP$\/70.#[9'`4B#P@&$P(@"=>K&`CT/'X``````#[9%`$B#Q0&(0@%(@\(!
MA,!U[>F<_O__@/H]#X5?____Z6G___\QP.EG____2(G&Z'?A__](A<!(B06!
M92``=!!)8\1(C1S%`````.G[_O__2(/$&+C_____6UU!7$%=05Y!7\,/'T0`
M`&8/'T0``$%7059)B?Y!54%40;SA44``55-(@^Q(3(L](AD``$F)Y4C'!"3A
M44``2,=$)`C744``2,=$)!#D44``2,=$)!C:44``2,=$)"#?44``2,=$)"CQ
M44``2,=$)#``````ZQY,B?9,B><QP.AR_?__38ME"$F#Q0A-A>0/A(D````Q
MP$R)Y^@W^O__2(7`2(G%=-"`.`!TRTR)]DB)Q^CKX/__2(7`=<A,B??H/M__
M_TR)_TB)P^@SW___2(U<`P%(B>_H)M___TB-/`/HG=W__TF)Z$B)QTB)PTR)
M^4R)\KX,4T``,<#HPM[__TR)YS'`2(G>Z.G\__]-BV4(28/%"$V%Y`^%=___
M_TB#Q$A;74%<05U!7D%?PV8/'X0``````$B#[#B__%%``$B+!4!?(`!(B40D
M*#'`2(L%TA<``$B)!"1(BP7/%P``2(E$)`A(BP7+%P``2(E$)!!(BP7'%P``
M2(E$)!@/MP7#%P``9HE$)"`QP.CW^/__,<"_!5)``.CK^/__,<"_#5)``.C?
M^/__,<"_%E)``.C3^/__,<"_'5)``.C'^/__,<"_+5)``.B[^/__,<"_.5)`
M`.BO^/__,<"_N%%``.BC^/__,<"_0E)``.B7^/__,<"_3%)``.B+^/__,<"_
M5E)``.A_^/__,<"_8U)``.AS^/__,<"_;%)``.AG^/__,<"_=U)``.BK^/__
M2(7`=`](B<:_0E)``#'`Z+?[__\QP+^(4D``Z(OX__](A<!T#TB)QK^:4D``
M,<#HE_O__S'`OZ520`#H:_C__TB%P'0V2(G&OSE20``QP.AW^___,<"^T5)`
M`+\=4D``Z&;[__](BT0D*$@S!>I=(`!U44B#Q#C##Q\`,<"_M5)``.@D^/__
M2(7`=!%(B<:_N%%``#'`Z##[___KMTB-="01O\920`"Y"@```/SSIG6C2(UT
M)!N_N%%``#'`Z`G[___KD.@^WO__9I!(@^P(Z(/=__^)Q^B<V___,=)(A<!T
M`TB+$$B)T$B#Q`C##Q^```````\?@`````!54TB)^TB#[`A(A?]T"`^V+T"$
M[7402(/$"+_#44``6UWI5MS__^BQW/__2`'82(U0_T@YTP^#G@```$B+/>85
M```/MD#_#[8W0#CP=`GK*@^V"CC!=69(@^H!2#G39I!R[D@YVG4I0#HO=*I(
M@\0(6UWI!=S__P^V`D`XQG3C2(/J`4@YTW+OZ]AF#Q]$``!(@^H!2#G3<PD/
MM@(Z!V:0=.Y(*=HQR4B-0@)(/0`$``!V#DB#Q`A(B<A;7<.)R.NY2(/"`4B)
MWK_`FV``Z"K=__^YP)M@`.O:2(L]2!4``.N`#Q^```````\?@`````!(B5PD
M\$B);"3X2(/L&$B)^^CZ_O__2(G'Z$+?__](B<4QP.BX]O__A<!T"DB%VW0%
M@#L`=0](BUPD"$B+;"002(/$&,.^TU)``$B)[^@ZW?__2#G%==](B=](BVPD
M$$B+7"0(2(/$&.G#]O__#Q\`4TB#["")?"0<2(ET)!!(C7PD'$B)5"0(2(UT
M)!!(C50D".AEW?__NEP90`"_G!I``$B)UN@CW/__@#T`7"```'4OZ+7:__](
MA<!(B<=(B05L8"``#X28`0``Z&W;__^+/7M;(`#H$MS__\:`G0<```"+/6E;
M(`#H`-S__X"(N@,```*+/5=;(`#H[MO__X"(N@,```&+1"0<@\`%2&/(2(7)
M#X@<`0``\D@/*L'R#U@%NU(``&8/+@6[4@``#X<>`0``2(T\S0````#H?-S_
M_TB+="002(G!2(D%^5\@`$R-2?A(BP9(QT$(V%)``$B)`4B+!=!:(`!(QT$8
MVU)``$B)01!$BT0D',<%O5\@``0```!!@_@!?B-,C4GXOP$```"Z"````$B+
M!!:#QP%(B40*&$B#P@A!.?A_ZT&-0`2^(%%``$4QP$B82<<$P0````"+5"0<
M2(L]8U\@`(/"`^C'V/__A<")PW1)2(L]3E\@`.CUVO__,<"_+5)``.C-]/__
M2(7`=!E(BSTQ7R``Z'C8___HP]G__XG82(/$(%O#2(L](%\@`$B%_W1-Z-[]
M___KU$B+/05?(`#HK-C__XG#ZZ=(B<A(B<I(T>B#X@%("=#R2`\JP/(/6,#I
MS/[__[Y0FV``O]110``QP.@:V___0+<!Z&+;__^_.5)``.A,]/__2(7`2(G'
M2(D%MUX@`'6:Z7#___\/'X0``````$%7059!54%428G\OSE20`!54TB)\TB!
M["@$``!(BP6]62``2(F$)!@$```QP.C^\___2(LM;Q(``$R)YTF)Q4B)[NBU
MVO__2(7`=#E,B>:_5E)``#'`Z/7V__](BY0D&`0``$@S%799(`!,B>`/A4X!
M``!(@<0H!```6UU!7$%=05Y!7\-,B>?HS]C__TR+/1P2``!(B=]!B<9,B?[H
M^M?__TB%P$B)PW2B08/&`42)="0,3(UT)!"`.P"XPU%``$@/1-A-A>UT$TB)
MWDR)[^C(VO__A<`/A)P```!(B=_H>-C__XG!2)@/MD0#_SI%`'4AC4'_2)A(
MC108#Q]$```/MD+_Q@(`@^D!2(/J`3I%`'3MBT0D#`'(/?\#```/CRC___]-
MB>!(B>E(B=J^#%-``$R)]S'`Z.#7__^+/7Y8(`#H%=G__TB-L)@!``!,B??H
M=M?__X7`=1Z+/6!8(`#H]]C__P^W@*`!```E`/```#T`@```=!LQ_TR)_N@:
MU___2(7`2(G##X4J____Z;G^__^^`0```$R)]^C,V/__A<!UU$R)]K]64D``
MZ)_U__],B??H0]?__TF)Q.F:_O__Z,;8__]F+@\?A```````05=)B?^_.5)`
M`$%6055!5%532('L:($``$B+!?!7(`!(B80D6($``#'`2,=$)%#>4D``2,=$
M)%CC4D``2,=$)&``````Z!;R__](A<!(B<-T"8`X``^%@0(``#'`2(UL)%#H
M&?K__TB%P$B)PP^$R`$``$B)W^@1U___2(U\``'HA]7__X`[`$F)Q70B2(G%
M#[832(GO,<"^\U)``$B#PP%(@\4"Z*+6__^`.P!UX4B-;"0@OYI20`!(QT0D
M()I20`!(QT0D*)-20`!(QT0D,/A20`!(QT0D.+!20`!(QT0D0`!30`!(QT0D
M2`````#K$4B+?0A(@\4(2(7_#X1E`0``,<#H5_'__TB%P$B)PW3@@#@`=-M(
MB<?H`O/__X7`=,](B=_H`M;__TB%P$F)Q`^$-`$``$R)Y^A.UO__3(GO2(G#
MZ$/6__^-A`,$!```3&/P3(GWZ+'4__](BQ5V#P``2(G'2(G%38GI0;C34D``
MO@I30``QP$B)T4B)5"003(GBZ,35__^^P`$``$B)[^B'UO__@\`!#X16`0``
MBSU,5B``Z./6__](C;"8`0``2(GOZ$36__^%P'4BBSTN5B``Z,76__\/MX"@
M`0``)0#P```]`$````^$4`$``$F+%TB+/:A6(`!(B>F^*%1``#'`,=OH0]7_
M_TB+E"18@0``2#,5"%8@`$B)V`^%B0(``$B!Q&B!``!;74%<05U!7D%?PTB)
MQ^@!U?__2(G#2(/%"$B%VP^%./[__TB+?0!(A?\/A$@"```QP.@1\/__2(7`
M=-J`.`!URDB#Q0A(A=MTV>D,_O__13'D@#VC#0```$C'1"1P!%-``+L$4T``
M2,=$)'C#44``2,>$)(``````````2(UL)'!U*.F6_O__387D#X6-_O__2(M=
M"$B%VP^$@/[__TB#Q0B`.P`/A'/^__](B=_H5?'__X7`=-%(B=_H5=3__TF)
MQ.O$2(G'Z+ST__](B=_H0-3__TB)P^D%____Z//5__^#.!$/'T``#X28_O__
MZ.'5__])BQ=$BP!(B>E(BSUU52``ONA30``QP#';Z!/4___IR_[__XL]O%0@
M`.A3U?__BYBD`0``Z,C4__\YPP^%DO[__XL]GE0@`.@UU?__#[>`H`$``"7_
M`0``/<`!```/A7#^__],B??HEM+__[_:44``2(G#,<#HV^[__TB%P$B)QP^$
MCP$``.B6T___28L_2(G&Z(_Z__](A<!)B<4/A',!``!,B>_HU]/__X/X`T&)
MP`^/Y````#'`Z+CN__^%P'46,?9,B>_HAM+__X7`B40D'`^%1@$``+[14D``
MO[A10``QP.B-\?__Z$35__](BTPD$$&)P$&Y45-``$B)ZKXL4T``2(G?,<!%
M,>3H,=/__^LXZ,K4__^#.!%U0.@0U?__2(M,)!!!@\0!08G`18GA2(GJOCI3
M0`!(B=\QP$C'!"114T``Z/?2__^^P`$``$B)W^BZT___@\`!=+9(B>_H#=7_
M_TB)WK\Y4D``,<#H`O'__TB)W^@:\___Z6[]__\/'T0``+OL4D``Z=G[__]F
M#Q]$``#H%]3__TB8OQ-30`!)C70%_+@%````_$B)P?.F#X7__O__08/X!'09
M08U`_$B+5"002)A!#[9$!?\Z`@^%X/[__TV+9PA-A>0/A-/^__],B>?HEM+_
M_TB#^`,/AL'^__])C70$_+\84T``N04```#\\Z9-#T3LZ:;^__\/'T0``$V+
M+^F%_O__N@(```!(Q\;N____B<?H0=+__XM\)!Q(C;0DD````+H&````Z&O2
M__^`O"20`````'4.@+PDD0```$,/A"<$``"+?"0<,?8QTDR-M"20@```Z/[1
M__^_B:O-[[[^W+J8N?#ATL-(QX0DD(````$C16=(B;PDF(```$F#QCA(B;0D
MH(```$C'A"2H@```=E0R$$B)C"2P@```2,>$)+B`````````2,>$),"`````
M````QX0D"($```````"+?"0<2(VT))````"Z`(```.C"T?__A<!!B<4/CC@!
M``!(BXPDN(```$ECU4B+A"3`@```3(VD))````"---%(.<Y(B;0DN(```$B#
MT`!(P>H=2(F$),"```!(`90DP(```(N4)`B!``"%TG1EZ8$```!)BP0D2(V\
M))"```!!@^U`2(F$),B```!)BT0D"$F)1@A)BT0D$$F)1A!)BT0D&$F)1AA)
MBT0D($F)1B!)BT0D*$F)1BA)BT0D,$F)1C!)BT0D.$F#Q$!)B48XZ(K4__]!
M@_T_?YI)8]5,B>9,B??H0M+__T2)K"0(@0``Z0W___^X0````$AC^DB-M"20
M````*=!)C3P^03G%08G$10].Y4UC_$R)^N@*TO__1(G@`X0D"($``(/X0(F$
M)`B!```/A<C^__](C8PDD````$4IY4B-O"20@```38TD#^@(U/__Z7G___^+
M?"0<Z!;0__],BZ0DN(```$R+K"3`@```3(G@2,'H`X/@/TACT(/``8/X.,:$
M%,B```"`#XZF`@``2&/XND`````Q]BG"2(V\/,B```!(8]+HN='__TB-O"20
M@```Z*#3__](C;PDD(```+D'````,<#\2(/'./-(JTR)Z$B-O"20@```1(BL
M)`.!``!(P>@81(BD)`>!``!,C;0D$($``(B$)`"!``!,B>A,C;PD0($``$C!
MZ!"(A"0!@0``3(GH38GU2,'H"(B$)`*!``!,B>!(P>@8B(0D!($``$R)X$C!
MZ!"(A"0%@0``3(G@13'D2,'H"(B$)`:!``#H`M/__TB+E"20@```2(G0B)0D
M0X$``$C!Z!B(A"1`@0``2(G02,'H$(B$)$&!``!(B=!(BY0DF(```$C!Z`B(
MA"1"@0``2(G0B)0D1X$``$C!Z!B(A"1$@0``2(G02,'H$(B$)$6!``!(B=!(
MBY0DH(```$C!Z`B(A"1&@0``2(G0B)0D2X$``$C!Z!B(A"1(@0``2(G02,'H
M$(B$)$F!``!(B=!(BY0DJ(```$C!Z`B(A"1*@0``2(G0B)0D3X$``$C!Z!B(
MA"1,@0``2(G02,'H$(B$)$V!``!(B=!(BY0DL(```$C!Z`B(A"1.@0``2(G0
MB)0D4X$``$C!Z!B(A"10@0``2(G02,'H$(B$)%&!``!(B=!(P>@(B(0D4H$`
M`$,/MA0\3(GO,<"^\U)``$F#Q`%)@\4"Z-7-__])@_P4==Y!N5%30`!-B?#&
MA"0X@0```.MQ@+PDD@```$$/A<O[__^`O"23````0P^%O?O__X"\))0```!(
M#X6O^___@+PDE0```$4/A:'[__^+?"0<N@(```!(Q\;&____Z)_-__^+?"0<
M2(VT))````"Z*0```.C)S?__3(V$))````!!N5%30`!(BTPD$$B)ZKX=4T``
M2(G?,<#H-,W__^E*^O__NC@```!(8_@Q]BG"2(V\/,B```!(8]+H$\___^EY
M_?__9I!!5T%6055!5%532('L&`0``(L]F4T@`$B+!;)-(`!(B80D"`0``#'`
MZ!_.__^_'5)``,:`J0````$QP.C@Y___2(7`=`F`.#$/A'X"```QP.@K[O__
MBSU532``Z.S-__^Y"P```$B)Q[H!````ODM30`#HY<O__TB%P`^$Q@```$4Q
M]H,]%E(@``%(BT`03(MX*`^.G````$&]`0```#'M0;P(````ZR](BW,02(L%
M]5$@`$J+/"#HT,[__X7`=71!C44!2(/%`4F#Q`@Y!<Y1(`!^74&)Q8L]TTP@
M`$&)[NAGS?__,<E(B<=(B>I,B?[H)\W__TB%P'0Z2(L8BT,,)0`$(``]``0`
M`'2<BSV>3"``Z#7-__](B=Y(B<>Y`@```#'2Z'/.__](B<;I>____T6)[HL5
M9E$@`(U"_T0Y\`^$4@$``(L]9$P@`.C[S/__N0,```!(B<>Z`0```+Y04T``
MZ/3*__](A<!(B<5T,TB+0!"+/39,(`!(BQCHRLS__[I24T``2(G'2(G>Z-K*
M__](BT402(L8]D,.0`^%`@(``(L]!TP@`.B>S/__N0,```!(B<>Z`0```+YU
M4D``Z)?*__](A<!(B<-T.#'`OU920`#H1^;__TB%P$B)Q0^$'`$``$B+0Q"+
M/<%+(`!(BQCH5<S__TB)ZDB)QTB)WNAGRO__BSVE2R``Z#S,__^_.5)``,:`
MJ0`````QP.C]Y?__2(7`2(D%:U`@``^$J````$B+/5Y0(`"^P`$``.B8R___
MA<!U)TB+A"0(!```2#,%>4L@``^%00$``$B!Q!@$``!;74%<05U!7D%?PX/X
M$734@_C_=,^)P4B+!290(`!(BQ4/4"``OZA40`!(BS`QP.A$S/__@^H!#XZE
M_O__NP$```"+/01+(`"#PP'HF,O__TR)_DB)Q^B-R?__.1W;3R``?]_I>O[_
M_X!X`0`/A'_]___I<_W__TB+/<9/(`#HV?+__TB%P$B)!:=/(``/A3S___^_
M@%1``.C;R___2(L%H$\@`(L]HDH@`$R+*$B+0Q!,BR#H+\O__[K_`P``2(GF
MOU=30`#HW<C__X7`B<)^1H/J`4ACVH`\'`!U6(72?C9(B=J^+P```$B)Y^A7
MRO__2(7`="&+/5!*(`#HY\K__TB)V4B)QTB)XDR)YNB6RO__Z8K^__^+/2]*
M(`#HQLK__TR)ZDB)QTR)YNC8R/__Z6S^__](8]CKIV:0Z-?*__^+/05*(`#H
MG,K__TB)WDB)Q^C1RO__Z>/]__](@^P(BSWF22``Z'W*__^YV%-``$B)Q[J,
M&D``OFI30`!(@\0(Z6++__]F#Q]$``!(@^P(BSVV22``Z$W*__](B<?HN?__
M_XL]HTD@`.@ZRO__0;A14T``2(G'13')3(G!NC!-0`"^AE-``$B#Q`CI6,G_
M_Y"0D)"0D)"0D)"0D%5(B>532(/L"$B+!1!%(`!(@_C_=!4QV__02(N#B)9@
M`$B#ZPA(@_C_=>U(@\0(6\G#D)!(@^P(Z-/+__](@\0(PP```````%!!4E]#
M3$5!3@`N+@`E<R\E<P`O<')O8R\E:2\E<P!,24)0051(`$193$1?3$E"4D%2
M65]0051(`%-(3$E"7U!!5$@`4$523#5,24(`4$523$Q)0@!015),-4]05`!0
M15),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]414U0`%!!
M4E]$14)51P!005)?0T%#2$4`4$%27U!23T=.04U%`%!!4E]!4D=#`%!!4E]!
M4D=67S``4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?
M5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#
M3$5!3CT`,0!P87(M`"UE`"TM`%5315(`55-%4DY!344`4UE35$5-`"4P,G@`
M5$5-4$1)4@!435``+W1M<"\`)7,E<R5S)7,`<&%R;``N<&%R`"5S)7-C86-H
M92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`
M<&5R;``O<')O8R]C=7)P<F]C+V9I;&4`1'EN84QO861E<CHZ8F]O=%]$>6YA
M3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`#H`````7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("````````````A30```````FU-```````!P
M97)L>'-I+F,`````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@```````"5S.B!P<FEV871E
M('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@
M86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H```````!5;F%B;&4@=&\@8W)E
M871E(&-A8VAE(&1I<F5C=&]R>0``````````)7,Z(&-R96%T:6]N(&]F('!R
M:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI
M"@``````````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K
M(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP
M86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T
M;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E
M($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@
M1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P
M87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@
M*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?
M=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2![
M"FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A8
M6%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I
M+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M
M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M
M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H
M96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@
M)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^
M9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O
M;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H
M<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A
M;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z
M.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FEF("AE>&ES=',@)$5.
M5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*0$%21U8@
M/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'
M0WT@+2`Q*3L*)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PIF;W(@
M*&ME>7,@)45.5BD@>PID96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O
M.PI]"GT*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I
M9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z
M("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\
M8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@
M/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA
M;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?
M<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?
M1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@
M)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U
M,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE
M(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R
M(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D
M;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@
M9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D
M;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA
M<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E
M="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D
M:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F
M9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E
M="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*
M)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0[
M"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA
M;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B
M+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["FUY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L
M("1C<F,I.PII9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T
M("1B=68["F-L;W-E("1O=70["F-H;6]D(#`W-34L("1F:6QE;F%M93L*?0HD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64[
M"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M
M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E
M9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`]("(D14Y6
M>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*;W5T<R@B4TA,24(Z("1F:6QE
M;F%M95QN(BD["F]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE
M("0A.PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E("1O
M=70["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z
M.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U
M9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@
M7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF
M+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M
M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M
M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER
M95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@
M)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F
M:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO
M861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@
M86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&
M:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I
M;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T
M=7)N("1F:#L*?0IE;'-E('L*;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL
M92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["FEF("@D;W5T*2!["F)I;FUO
M9&4H)&]U="D["G!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*8VQO<V4@
M)&]U=#L*?0IO<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["F)I
M;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@
M9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E
M<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI
M;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;
M,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^
M("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR
M97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S
M<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE
M=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B
M=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H
M+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C
M('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD
M<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T
M7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T
M*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I
M;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@
M('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR
M975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S
M:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*
M;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O
M7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@
M)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G
M32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N
M<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O
M=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET
M92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*
M96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E
M<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#
M86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C
M86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]
M("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN
M:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C
M;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I
M(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I
M;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY
M("1Z:7`["FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#
M:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R
M(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*
M8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@
M97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@
M)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]
M?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A
M(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@
M9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO
M="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]
M"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD
M;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*
M8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A
M=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@
M<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO
M861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L
M>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@
M)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@
M979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?
M14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B
M("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K
M*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG
M=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U
M;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I
M<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R
M97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#
M;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP
M<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@
M9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)
M3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM
M>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H
M)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D
M;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@
M)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO
M:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF
M("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E
M9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D
M;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D
M,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0[
M"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I
M='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@
M/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI
M;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H
M(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT
M96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@
M)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H
M1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*
M:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\
M:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P
M<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T
M96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I
M;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H
M<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S
M,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L
M96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*
M)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?
M;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE
M7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D
M8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!
M+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I
M9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-
M1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A
M;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E
M<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*
M)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*
M:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E
M*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C
M86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*
M?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N
M86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C
M:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE
M;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F
M:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N
M;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q
M=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR
M97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D
M(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA
M;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"([
M"G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P
M<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO
M=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T
M(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE
M;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M
M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D
M;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF
M:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I
M/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E
M<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL
M("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]
M("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P
M:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T
M("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@
M(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X
M=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E
M<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@
M0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-
M;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM
M8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E
M4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA
M;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z
M.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P
M871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?
M;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E
M<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN
M9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z
M.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&
M:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D
M97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I
M<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q
M=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![
M(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL
M('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE
M=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L
M('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*
M979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!]
M(#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A
M8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!4
M35!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@
M+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T
M:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L
M('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF
M("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]
M("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@
M>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%
M3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S
M97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF
M:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY
M("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F
M:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D
M("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E
M96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]
M?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M
M(B`N("1B=68["GT*96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!]
M.PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)3
M24].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H
M85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M
M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N
M*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M
M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG
M97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM0
M05)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E
M;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S
M=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B
M(%]T96UP9FEL92!["FUY("@D97AT+"`D8W)C*2`]($!?.PIM>2`H)&9H+"`D
M9FEL96YA;64I.PHD9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*
M:68@*"1%3E9[4$%27T-,14%.?2D@>PIU;FQI;FL@)&9I;&5N86UE(&EF("UE
M("1F:6QE;F%M93L*<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PI]"F5L<V4@
M>PIR971U<FX@*'5N9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I
M.PI]"F]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["F)I;FUO
M9&4H)&9H*3L*<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0IS=6(@7W-E=%]P
M<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@
M)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D
M,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD
M(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R
M;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!
M345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P
M*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N
M(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF
M;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O
M+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!]
M(&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N
M9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL*
M*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I
M+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92([
M"GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D
M14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T
M8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#
M=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*
M)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO
M)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?
M24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6
M>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-
M4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@
M>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!4
M14U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG
M4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D
M14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/
M0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@
M,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I
M9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@
M>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F
M:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET
M7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE
M9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R
M:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP
M('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005([
M"G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`
M<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R
M:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI
M"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI
M="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`
M(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI
M="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``
M``````````````````````#`0P$;`SO$````%P```&"*___@````<(O__P@!
M``"PB___(`$``*"A__]0`0``@*+__W@!``#0HO__F`$``/"B__^P`0``0*/_
M_\@!``"0I/__Z`$``!"E__\``@``X*7__R`"``#PI?__.`(``!"H__]P`@``
M,*G__Z@"``#PJO__P`(``""K___8`@``$*S___@"``"`K/__$`,``*"N__\P
M`P``<+#__V@#``"PNO__H`,``'"^___8`P``H+[___`#````````%```````
M```!>E(``7@0`0,,!PB0`0``)````!P```#@'$``G`````!!#A"&`D,-!D*-
M`TN#!8P$`````````!0```!$````\!U``#0``````````````"P```!<````
M,!Y``/`5````0@X01@X80@X@00XHA@6,!(T#C@)$#C!'#K@$@P8``"0```",
M````(#1``-D`````2H\"C`5>#D".`XT$A@:#!P`````````<````M``````U
M0`!/`````$$.$$$.&(,#A@)'#C```!0```#4````4#5``!4`````1`X@````
M`!0```#L````<#5``$T`````1`X0`````!P````$`0``P#5``$(!````2H,&
MC`19#K`!C@*-`X8%%````"0!```0-T``>0````!!#A"#`@``'````#P!``"0
M-T``R0````!6#L`0C`*&`X,$```````4````7`$``&`X0``%````````````
M```T````=`$``'`X0``5`@```$(.$$0.&(X#CP)%#B!"#BA!#C"&!HP%C01$
M#CA$#E"#!P```````#0```"L`0``D#I``!<!````0@X00@X8C@./`D4.($(.
M*(P%C01'#C!!#CA$#H`!@P>&!@``````%````.0!``"P.T``O@$```!$#D``
M````%````/P!``!P/4``(@````!$#A``````'````!0"``"@/4``X@````!!
M#A!!#AB#`X8"1PX@```4````-`(``)`^0`!M`````$X.((8"@P,<````3`(`
M```_0``8`@```$$.$$0.,(,"`````````#0```!L`@``($%``,8!````0@X0
M0@X80@X@0@XHC`6-!(X#CP))#C!!#CB#!X8&2@[@"```````-````*0"``#P
M0D``/@H```!"#A"/`DH.&$(.($(.*$$.,$$..$<.H(,"@P>&!HP%C02.`P``
M```T````W`(``#!-0`#``P```$(.$$(.&$(.($(.*$$.,$$..$<.T`B#!X8&
MC`6-!(X#CP(``````!0````4`P``\%!``"H`````1`X0`````!0````L`P``
M(%%``$0`````1`X0````````````````__________\``````````/______
M____``````````````````````$``````````0`````````!`````````%P`
M`````````0````````#C`0````````$`````````[0$````````!````````
M`/L!`````````0`````````(`@````````\`````````,0,````````,````
M`````-@80```````#0````````"D44````````0`````````,`)````````%
M`````````%@-0```````!@````````"X!$````````H`````````.00`````
M```+`````````!@`````````%0````````````````````,`````````J)A@
M```````"`````````-`%````````%``````````'`````````!<`````````
M"!-````````'`````````)`20```````"`````````!X``````````D`````
M````&`````````#^__]O`````%`20```````____;P`````"`````````/#_
M_V\`````DA%`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````"XEF`````````````````````````````"
M&4```````!(90```````(AE````````R&4```````$(90```````4AE`````
M``!B&4```````'(90```````@AE```````"2&4```````*(90```````LAE`
M``````#"&4```````-(90```````XAE```````#R&4````````(:0```````
M$AI````````B&D```````#(:0```````0AI```````!2&D```````&(:0```
M````<AI```````""&D```````)(:0```````HAI```````"R&D```````,(:
M0```````TAI```````#B&D```````/(:0````````AM````````2&T``````
M`"(;0```````,AM```````!"&T```````%(;0```````8AM```````!R&T``
M`````((;0```````DAM```````"B&T```````+(;0```````PAM```````#2
M&T```````.(;0```````\AM````````"'$```````!(<0```````(AQ`````
M```R'$```````$(<0```````4AQ```````!B'$```````'(<0```````@AQ`
M``````"2'$```````*(<0```````LAQ```````#"'$```````-(<0```````
M45-``````````````````*B68```````\%1```````#_____`"1&<F5E0E-$
M.B!R96QE87-E+SDN,2XP+VQI8B]C<W4O86UD-C0O8W)T,2YC(#(Q-C,S."`R
M,#$P+3$R+3`Y(#(Q.C,Q.C(Q6B!D:6T@)``D1G)E94)31#H@<F5L96%S92\Y
M+C$N,"]L:6(O8W-U+V-O;6UO;B]C<G1B<F%N9"YC(#(Q-S,W-2`R,#$Q+3`Q
M+3$S(#(P.C0T.C,Q6B!D:6T@)`!'0T,Z("A'3E4I(#0N,BXQ(#(P,#<P.#,Q
M('!A=&-H960@6T9R965"4T1=```D1G)E94)31#H@<F5L96%S92\Y+C$N,"]L
M:6(O8W-U+V%M9#8T+V-R=&DN4R`R,3<Q,#4@,C`Q,2TP,2TP-R`Q-CHP-SHU
M,5H@:VEB("0``$=#0SH@*$=.52D@-"XR+C$@,C`P-S`X,S$@<&%T8VAE9"!;
M1G)E94)31%T``$=#0SH@*$=.52D@-"XR+C$@,C`P-S`X,S$@<&%T8VAE9"!;
M1G)E94)31%T``$=#0SH@*$=.52D@-"XR+C$@,C`P-S`X,S$@<&%T8VAE9"!;
M1G)E94)31%T``"1&<F5E0E-$.B!R96QE87-E+SDN,2XP+VQI8B]C<W4O86UD
M-C0O8W)T;BY3(#(Q-S$P-2`R,#$Q+3`Q+3`W(#$V.C`W.C4Q6B!K:6(@)```
M+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N:&%S:``N9'EN<WEM
M`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y
M;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A
M;65?:&1R`"YE:%]F<F%M90`N8W1O<G,`+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`
M+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````
M````````````````````````````````````````````````````````````
M````````"P````$````"```````````"0`````````(````````5````````
M`````````````0```````````````````!,````'`````@`````````8`D``
M`````!@"````````&`````````````````````0````````````````````A
M````!0````(`````````,`)````````P`@```````(0"````````!```````
M```(``````````0`````````)P````L````"`````````+@$0```````N`0`
M``````"@"`````````4````!````"``````````8`````````"\````#````
M`@````````!8#4```````%@-````````.00```````````````````$`````
M```````````````W````____;P(`````````DA%```````"2$0```````+@`
M````````!``````````"``````````(`````````1````/[__V\"````````
M`%`20```````4!(```````!```````````4````"````"```````````````
M`````%,````$`````@````````"0$D```````)`2````````>``````````$
M``````````@`````````&`````````!=````!`````(`````````"!-`````
M```($P```````-`%````````!`````L````(`````````!@`````````9P``
M``$````&`````````-@80```````V!@````````3````````````````````
M!````````````````````&(````!````!@````````#L&$```````.P8````
M````\`,```````````````````0`````````$`````````!M`````0````8`
M````````X!Q```````#@'````````,0T```````````````````0````````
M````````````<P````$````&`````````*110```````I%$````````.````
M````````````````!````````````````````'D````!`````@````````"X
M44```````+A1````````R$````````````````````@`````````````````
M``"!`````0````(`````````@))```````"`D@```````,0`````````````
M```````$````````````````````CP````$````"`````````$B30```````
M2),```````!$`P``````````````````"````````````````````)D````!
M`````P````````"0EF```````)"6````````$`````````````````````@`
M``````````````````"@`````0````,`````````H)9@``````"@E@``````
M`!`````````````````````(````````````````````IP````$````#````
M`````+"68```````L)8````````(````````````````````"```````````
M`````````*P````&`````P````````"XEF```````+B6````````\`$`````
M```%``````````@`````````$`````````"U`````0````,`````````J)A@
M``````"HF`````````@"```````````````````(``````````@`````````
MO@````$````#`````````+":8```````L)H````````D````````````````
M````"````````````````````,0````(`````P````````#@FF```````-2:
M````````"`4``````````````````"````````````````````#)`````0``
M``````````````````````#4F@```````/<!```````````````````!````
M`````````````````0````,`````````````````````````RYP```````#2
?`````````````````````0``````````````````````
